@@ -16,7 +16,7 @@ SUBROUTINE maxlambda(nvars, nobs, x, y, gamma, gindex, ngroups, pf, maxlam)
     INTEGER :: k, c, nzvars
     INTEGER :: gstart, gend, gs, gj
     DOUBLE PRECISION :: gw, xy(nvars), r(nobs)
-    DOUBLE PRECISION :: wmaxg(ngroups), lb, rb, NORM2
+    DOUBLE PRECISION :: wmaxg(ngroups), lb, rb
 
     ! -------- BEGIN PROGRAM -------- !
     c = 0
@@ -53,8 +53,8 @@ SUBROUTINE maxlambda(nvars, nobs, x, y, gamma, gindex, ngroups, pf, maxlam)
                 wmaxg(k) = 0.0D0
             ELSE
                 IF (gamma .EQ. 0.0D0) THEN
-                    rb = NORM2(xy(gstart:gend))
-                    !rb = SQRT(DOT_PRODUCT(xy(gstart:gend), xy(gstart:gend)))
+                    !rb = NORM2(xy(gstart:gend))
+                    rb = SQRT(DOT_PRODUCT(xy(gstart:gend), xy(gstart:gend)))
                     wmaxg(k) = rb/gw
                 ELSE
                     lb = 0.0D0
